@@ -69,22 +69,6 @@ bool PhonedevTrunk::sleepHandler(TrunkEvent *event)
 			TrunkSignal(TRUNK_SIGNAL_STEP);
 		handler = &PhonedevTrunk::stepHandler;
 		return true;
-	case TRUNK_SERVICE_LOGIN:
-		if(event->parm.lookup.seq != tgi.seq)
-			return false;
-		Logout();
-		if(event->parm.lookup.result)
-		{
-			session = event->parm.lookup.data;
-			TrunkSignal(TRUNK_SIGNAL_STEP);
-		}
-		else
-		{
-			setSymbol("error", event->parm.lookup.data);
-			TrunkSignal(TRUNK_SIGNAL_ERROR);
-		}
-		handler = &PhonedevTrunk::stepHandler;
-		return true;
 	case TRUNK_SERVICE_LOOKUP:
 		if(event->parm.lookup.seq != tgi.seq)
 			return false;
