@@ -63,7 +63,8 @@ bool PikaTrunk::collectHandler(TrunkEvent *event)
 		setTimer(data.collect.timeout);
 		return true;
 	case TRUNK_TIMER_EXPIRED:
-		TrunkSignal(TRUNK_SIGNAL_TIMEOUT);
+		if(!TrunkSignal(TRUNK_SIGNAL_TIMEOUT))		
+			TrunkSignal(TRUNK_SIGNAL_STEP);	
 		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_DTMF_KEYUP:
