@@ -92,8 +92,10 @@ private:
 	static char *status;
 	static void callback(PK_U32 id, PK_U32 event, PK_U32 p1, PK_U32 p2);
 
-	TBufferHeader hTone;
+	TBufferHeader hTone, *headers;
 	TResourceHandle hTrk, hDsp, hTimer;
+	unsigned char *buffers;
+	unsigned bufsize;
 	trunknti_t nti;
 	trunkhandler_t handler;
 	int card;
@@ -140,6 +142,15 @@ private:
 public:
 	inline TResourceHandle getDevice(void)
 		{return hDsp;};
+
+	inline TBufferHeader *getHeaders(void)
+		{return headers;};
+
+	inline unsigned char *getBuffers(void)
+		{return buffers;};
+
+	inline unsigned getBufferSize(void)
+		{return bufsize;};
 };
 
 class PikaRecord : private AudioFile, public Service
@@ -149,6 +160,9 @@ private:
 	bool reset;
 	size_t bufsize;
 	unsigned samples;
+	TBufferHeader *control;
+	unsigned char *buffer;
+	unsigned buflimit;
 
 	void Initial(void);
 	void Run(void);
@@ -166,6 +180,9 @@ private:
 	bool reset;
 	size_t bufsize;
 	unsigned samples;
+	TBufferHeader *control;
+	unsigned char *buffer;
+	unsigned buflimit;
 
 	void Initial(void);
 	void Run(void);
