@@ -81,22 +81,6 @@ bool PikaTrunk::sleepHandler(TrunkEvent *event)
 		if(rings < data.sleep.rings)
 			return true;
 		endTimer();
-	case TRUNK_SERVICE_LOGIN:
-		if(event->parm.lookup.seq != tgi.seq)
-			return false;
-		Logout();
-		if(event->parm.lookup.result)
-		{
-			session = event->parm.lookup.data;
-			TrunkSignal(TRUNK_SIGNAL_STEP);
-		}
-		else
-		{
-			setSymbol("error", event->parm.lookup.data);
-			TrunkSignal(TRUNK_SIGNAL_ERROR);
-		}
-		handler = &PikaTrunk::stepHandler;
-		return true;
 	case TRUNK_SERVICE_LOOKUP:
 		if(event->parm.lookup.seq != tgi.seq)
 			return false;
@@ -134,7 +118,8 @@ bool PikaTrunk::sleepHandler(TrunkEvent *event)
 		{
 			kill(tgi.pid, SIGALRM);
 			tgi.pid = 0;
-			TrunkSignal(TRUNK_SIGNAL_TIMEOUT);
+			if(!TrunkSignal(TRUNK_SIGNAL_TIMEOUT))
+				TrunkSignal(TRUNK_SIGNAL_STEP);
 		}
 		else
 			TrunkSignal(TRUNK_SIGNAL_STEP);
