@@ -50,6 +50,7 @@ PikaTrunk::PikaTrunk(TResourceHandle hRes, trunknti_t port, int c, int ts) :
 Trunk(ts), TimerPort()
 {
 	TrunkEvent event;
+	int bufcount = pikaivr.getAudioBuffers();
 
 	hDsp = 0;
 	hTrk = hRes;
@@ -59,6 +60,10 @@ Trunk(ts), TimerPort()
 	hTimer = PK_TIMER_Create();
 	handler = NULL;
 
+	headers = new TBufferHeader[bufcount];
+	bufsize = bufcount * 960 + 960;
+	buffers = new unsigned char[bufsize * bufcount];
+
 	PK_TIMER_SetEventHandler(hTimer, (PK_U32)id, (pikacall_t)&PikaTrunk::callback);
 	PK_TRUNK_SetEventHandler(hTrk, (PK_U32)id, (pikacall_t)&PikaTrunk::callback);
 
@@ -84,6 +89,9 @@ PikaTrunk::~PikaTrunk()
 	PK_TRUNK_SetEventHandler(hTrk, 0xffff, (pikacall_t)&PikaTrunk::callback);
 	PK_TRUNK_ReleaseResource(hTrk);
 	PK_TIMER_Delete(hTimer);
+
+	delete[] headers;
+	delete[] buffers;
 }
 
 void PikaTrunk::getCIDResource(void)
@@ -308,7 +316,8 @@ retry:
 		goto retry;
 		break;
 	case TRUNK_TIMER_EXPIRED:
-		TrunkSignal(TRUNK_SIGNAL_TIMEOUT);
+		if(!TrunkSignal(TRUNK_SIGNAL_TIMEOUT))
+			TrunkSignal(TRUNK_SIGNAL_STEP);
 		event->id = TRUNK_STOP_STATE;
 		goto retry;
 		break;
