@@ -19,7 +19,7 @@
 int VPBThread::count = 0;
 
 VPBThread::VPBThread() :
-Thread(NULL, keythreads.priService()), Mutex()
+Thread(NULL, keythreads.priService(), vpbivr.getStack()), Mutex()
 {
 	id = ++count;
 	active = false;
