@@ -627,6 +627,75 @@ public:
 		{return getLast("precache");};
 };
 
+/**
+ * Load /etc/bayonne [network] key value pairs.  These are used to
+ * specify dilu access methods and bindings.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short Load database access bindings.
+ */
+class KeyNetwork : public Keydata
+{
+public:
+	/**
+	 * Initialize keydatabase data.
+	 */
+	KeyNetwork();
+
+	/**
+	 * Get refresh timer in seconds for inter-node activity.
+	 *
+	 * @return refresh in seconds.
+	 */
+	unsigned getRefresh(void)
+		{return atoi(getLast("refresh"));};
+
+	/**
+	 * Get time delay for transactions.
+	 *
+	 * @return time delay in seconds.
+	 */
+	unsigned getDatabaseDelay(void)
+		{return atoi(getLast("databasedelay"));};
+
+	/**
+	 * Get broadcast address to use.
+	 *
+	 * @return broadcast address.
+	 */
+	InetHostAddress getBroadcast(void);
+
+	/**
+	 * Get bind address to use.
+	 *
+	 * @return binding address.
+	 */
+	InetAddress getAddress(void);
+
+	/**
+	 * Get port for binding.
+	 *
+	 * @return port.
+	 */
+	tpport_t getPort(void);
+
+	/**
+	 * Get adapter address for a specific connection.
+	 *
+	 * @param adapter id.
+	 * @return adapter address.
+	 */
+	InetHostAddress getDatabase(unsigned id);
+
+	/**
+	 * Get adapter port address for a specific connection.
+	 *
+	 * @param adapter id.
+	 * @return adapter port.
+	 */
+	tpport_t getDatabasePort(unsigned id);
+};
+
 /**
  * Load /etc/bayonne [mailbox] key value pairs.  These are used to
  * specify default values to initialize newly created mailboxes.
@@ -868,12 +937,12 @@ public:
 		{return atoi(getLast("managers"));};
 
 	/**
-	 * Get the relative priority for a lookup thread.
+	 * Get the relative priority for network service thread.
 	 *
 	 * @return priority for lookup thread.
 	 */
-	inline int priDatabase(void)
-		{return atoi(getLast("database"));};
+	inline int priNetwork(void)
+		{return atoi(getLast("network"));};
 
 	/**
 	 * Scheduler execution interval.
@@ -1157,16 +1226,6 @@ public:
 	 */
 	DSO *loadDriver(void);
 
-	/**
-	 * Load status monitoring subsystem.
-	 */
-	DSO *loadStatMon(void);
-
-	/**
-	 * Load the lookup dso module.
-	 */
-	void loadDatabase(void);
-
 	/**
 	 * Load automatic application extensions module.
 	 */
@@ -1348,11 +1407,7 @@ private:
 	bool scrTransfer(void);
 	bool scrSpeak(void);
 	bool scrLookup(void);
-	bool scrLogin(void);
-	bool scrLogout(void);
-	bool scrSession(void);
-	bool scrRetry(void);
-	bool scrSubmit(void);
+	bool scrUpdate(void);
 	bool scrDeliver(void);
 	bool scrSendfile(void);
 	bool scrNotify(void);
@@ -1363,7 +1418,6 @@ protected:
 	static char digit[16];
 	ScriptInterface *script;
 	TrunkGroup *group;
-	void *session;
 	PortManager *manager;
 	int id;
 	time_t start, idle;
@@ -1552,14 +1606,6 @@ public:
 	 */
 	virtual bool postEvent(TrunkEvent *event) = 0;
 
-	/**
-	 * Get a session object.
-	 *
-	 * @return pointer to trunk session object.
-	 */
-	inline void *getSession(void)
-		{return session;};
-
 	/**
 	 * Compute the DTMF digit id of a character.
 	 *
@@ -1567,10 +1613,6 @@ public:
 	 */
 	int getDigit(char digit);
 
-	/**
-	 * Logout a session handler.
-	 */
-	void Logout(void);
 };
 
 /**
@@ -2018,110 +2060,6 @@ public:
 
 };
 
-/**
- * The lookup class provides a interface to scalable database lookup
- * services.  These are commonly used in transactional ivr systems.
- * scalable lookup is supported by the state engine drivers, and could
- * allow for udp broadcast of database queries.
- *
- * @short database lookup.
- * @author David Sugar <dyfet@ostel.com>
- */
-class Database
-{
-protected:
-	friend class Trunk;
-	Database();
-
-	/**
-	 * Initialize script environment.
-	 *
- 	 * @param trunk handle.
-	 */
-	virtual void Initialize(Trunk *trunk)
-		{return;};
-
-	/**
-	 * Finalize script environment.
-	 *
-	 * @param trunk handler.
-	 */
- 	virtual void Finalize(Trunk *trunk)
-		{return;};
-
-	/**
-	 * Post lookup request.  This could send a packet or reply
-	 * immediately.  A negative value indicates an error.
-	 *
-	 * @return execution delay for transaction to sleep.
-	 * @param trunk handle.
-	 */
-	virtual int Lookup(unsigned seq, Trunk *trunk) = 0;
-
-	/**
-	 * Support submit requests which may spawn seperate
-	 * threads.
-	 *
-	 * @return error message or successful.
-	 * @param trunk handle.
-	 */
-	virtual char *Submit(Trunk *trunk)
-		{return "submit-not-supported";};
-
-	/**
-	 * Support login request if resource sets sessions.
-	 *
-	 * @return execution delay for transaction to sleep.
-	 * @param trunk handle.
-	 */
-	virtual int Login(unsigned seq, Trunk *trunk)
-		{return -1;};
-
-	/**
-	 * Logout and disconnect an active session object.
-	 *
-	 * @param trunk handle.
-	 */
-	virtual void Logout(Trunk *trunk)
-		{return;};
-
-	/**
-	 * Mailbox session request, assumes login as well.
-	 *
-	 * @return execution delay for transaction to sleep.
-	 * @param trunk handle.
-	 */
-	virtual int Session(unsigned seq, char *keyword, Trunk *trunk)
-		{return -1;};
-
-public:
-	/**
-	 * Get size of database login object.
-	 *
-	 * @return number of bytes to "store" %login.
-	 */
-	virtual int getLoginSize(void)
-		{return 64;};
-
-	/**
-	 * Return list of session keywords.
-	 *
-	 * @return NULL terminated keyword list.
-	 */
-	virtual char **getKeywords(void)
-		{return NULL;};
-
-	/**
-	 * Connect the database.  This may start thread(s).
-	 */
-	virtual void Connect(void) = 0;
-
-	/**
-	 * Disconnect is used during shutdown.
-	 */
-	virtual void Disconnect(void) = 0;	 
-};
-
 /**
  * Server classes are used for threaded entities such as network
  * management interfaces, which may be started and stopped under
@@ -2260,35 +2198,6 @@ public:
 		{return duration;};
 };
 
-/**
- * Status monitoring plugin interface.  The status monitor allows
- * some form of network node monitoring and may offer other features
- * at a later time.
- *
- * @author David Sugar <dyfet@ostel.com>
- * @short network status monitoring.
- */
-class StatMon : public Keydata
-{
-public:
-	StatMon();
-
-	/**
-	 * Fetch a status monitoring entity for a given node.
-	 *
-	 * @return node status record.
-	 * @param status monitoring node to request.
-	 */
-	virtual statnode_t *getNode(const char *name) = 0;
-
-	/**
-	 * Used by the scheduler.
-	 *
-	 * @param number of seconds to occupy.
-	 */
-	virtual void Refresh(int seconds) = 0;	
-};
-
 /**
  * This class is used for interfacing to DSO loaded TGI interpreters.
  *
@@ -2426,6 +2335,38 @@ protected:
 	virtual time_t getExpires(void) = 0;
 };
 
+/**
+ * Audio feeds provide a means for buffering audio for distribution thru
+ * one or more telephony ports.  These feeds are used either for one-way
+ * conferences or to source music on hold/bgm features for a given caller.
+ *
+ * @short feed audio to multiple ports.
+ * @author David Sugar <dufet@ostel.com>
+ */
+class AudioFeed : private ThreadLock
+{
+private:
+	static AudioFeed *first;
+	AudioFeed *next;
+	unsigned char *buffers;
+	volatile unsigned char *current;
+	size_t feedsize, bufsize;
+	bool active;
+
+protected:
+	const char *name;
+
+public:
+	AudioFeed(const char *name, unsigned buffers);
+	~AudioFeed();
+	bool Enable(void);
+	void Disable(void);
+	unsigned char *getBuffer(unsigned char *prior = NULL, unsigned size = 120);
+	void putBuffer(unsigned char *buffer, unsigned size = 120);
+
+	friend AudioFeed *getAudioFeed(const char *name);
+};
+
 /**
  * Protocols are used for processing transactional requests such as
  * those performed thru modules, but thru a TCP protocol.  These support
@@ -2478,14 +2419,13 @@ extern KeyThreads keythreads;
 extern KeyMemory keymemory;
 extern KeyPaths keypaths;
 extern KeyLocal keylocal;
+extern KeyNetwork keynetwork;
 extern KeyMailbox keymailbox;
 extern KeyTones keytones;
 extern KeyFeed keyfeed;
 extern Plugins plugins;
 extern Driver *driver;
-extern StatMon *statmon;
 extern Debug *debug;
-extern Database *database;
 extern Fifo fifo;
 #endif
 
