@@ -152,7 +152,7 @@ Keydata("/bayonne/threads")
 	{"priority", "0"},
 	{"gateways", "0,1"},
 	{"services", "1,1"},
-	{"database", "0"},
+	{"network", "0"},
 	{"managers", "0"},
 	{"scheduler", "0"},
 	{"resetdelay", "18"},
@@ -189,6 +189,89 @@ int KeyThreads::getPolicy()
 	return 0;
 }
 
+KeyNetwork::KeyNetwork() :
+Keydata("/bayonne/database")
+{
+	static KEYDEF defkeys[] = {
+	{"databasedelay", "8"},
+	{"refresh", "5"},
+	{"address", "127.0.0.1:7001"},
+	{"broadcast", "127.255.255.255"},
+	{"database0", "127.0.0.1:7000"},
+	{NULL, NULL}};
+
+	Load("~bayonne/database");
+	Load(defkeys);
+}
+
+
+
+InetAddress KeyNetwork::getAddress(void)
+{
+	char buffer[65];
+	char *cp;
+
+	strcpy(buffer, getLast("address"));
+	cp = strchr(buffer, ':');
+	if(*cp)
+		*cp = 0;
+	return InetAddress(buffer);
+}
+
+InetHostAddress KeyNetwork::getBroadcast(void)
+{
+	return InetHostAddress(getLast("broadcast"));
+}
+
+tpport_t KeyNetwork::getPort(void)
+{
+	char buffer[65];
+	char *cp;
+
+	strcpy(buffer, getLast("address"));
+	cp = strchr(buffer, ':');
+	if(cp)
+		return atoi(++cp);
+	return 0;
+}
+
+tpport_t KeyNetwork::getDatabasePort(unsigned id)
+{
+	char buffer[65];
+	char adapter[12];
+	char *cp;
+
+	sprintf(adapter, "database%u", id);
+	cp = (char *)getLast(adapter);
+	if(!cp)
+		return 0;
+
+	strcpy(buffer, cp);
+	cp = strchr(cp, ':');
+	if(!cp)
+		return 0;
+
+	return atoi(++cp);
+}
+
+InetHostAddress KeyNetwork::getDatabase(unsigned id)
+{
+	char buffer[65];
+	char adapter[12];
+	char *cp;
+
+	sprintf(adapter, "database%u", id);
+	cp = (char *)getLast(adapter);
+	if(!cp)
+		return InetHostAddress("0.0.0.0");
+
+	strcpy(buffer, cp);
+	cp = strchr(buffer, ':');
+	if(*cp)
+		*cp = 0;
+	return InetHostAddress(buffer);
+}
+	
 KeyMailbox::KeyMailbox() :
 Keydata("/bayonne/mailbox")
 {
@@ -295,12 +378,7 @@ int KeyThreads::getGateways(void)
 Plugins::Plugins() :
 Keydata("/bayonne/plugins")
 {
-	static KEYDEF defplugs[] = {
-		{"database", "default"},
-		{NULL, NULL}};
-
 	Load("~bayonne/plugins");
-	Load(defplugs);
 
 	if(getLast("driver"))
 		return;
@@ -580,24 +658,6 @@ void Plugins::loadExtensions(void)
 		new DSO(path);
 }
 
-void Plugins::loadDatabase(void)
-{
-	char path[256];
-	char *d = (char *)getLast("database");
-
-	if(*d != '/')
-	{
-		strcpy(path, keypaths.getLibpath());
-		strcat(path, LIB_VERSION);
-		strcat(path, d);
-		strcat(path, ".dba");			
-		d = path;
-	}
-	if(canAccess(d))
-		new DSO(d);
-}
-
-
 void Plugins::loadDebug(void)
 {
 	char path[256];
@@ -620,25 +680,6 @@ void Plugins::loadDebug(void)
 	new DSO(d);
 }
 	
-DSO *Plugins::loadStatMon(void)
-{
-	char path[256];
-	char *s = (char *)getLast("statmon");
-
-	if(!s)
-		return NULL;
-
-	if(*s != '/')
-	{
-		strcpy(path, keypaths.getLibpath());
-		strcat(path, LIB_VERSION);
-		strcat(path, s);
-		strcat(path, ".mon");
-		s = path;
-	}
-	return new DSO(s);
-}
-
 DSO *Plugins::loadDriver(void)
 {
 	char path[256];
@@ -891,12 +932,14 @@ KeyServer keyserver;
 KeyPaths keypaths;
 KeyLocal keylocal;
 KeyMailbox keymailbox;
+KeyNetwork keynetwork;
 KeyTones keytones;
 KeyThreads keythreads;
 KeyMemory keymemory;
 KeyFeed keyfeed;
 Plugins plugins;
 Scheduler scheduler;
+Network network;
 
 ScriptSymbol Trunk::globals(keymemory.getSymbolSize(), keymemory.getPageSize());
 
