@@ -55,37 +55,6 @@ bool Fifo::setSymbol(char **argv)
 	return true;
 }
 
-bool Fifo::login(char **argv)
-{
-	Trunk *trunk = getTrunk(argv[1]);
-	TrunkEvent event;
-	char *buffer;
-
-	if(!trunk || !argv[2])
-		return false;
-
-	if(!database)
-		return false;
-
-	trunk->setSymbol("login", database->getLoginSize());
-	buffer = trunk->getSymbol("login");
-	if(buffer)
-		if(*buffer)
-			trunk->Logout();
-
-	trunk->setSymbol("login", "");
-	event.parm.lookup.data = trunk->getSymbol("login");
-	event.parm.lookup.seq = atoi(argv[2]);
-	event.parm.lookup.result = true;
-	event.id = TRUNK_SERVICE_LOGIN;
-	if(trunk->postEvent(&event))
-	{
-		trunk->setSymbol("login", argv[3]);
-		return true;
-	}
-	return false;
-}	
-
 bool Fifo::submit(char **argv)
 {
 	Trunk *trunk = getTrunk(argv[1]);
@@ -282,8 +251,6 @@ bool Fifo::Command(const char *cmd)
 		rts = setSymbol(argv);
 	else if(!stricmp(argv[0], "submit"))
 		rts = submit(argv);
-	else if(!stricmp(argv[0], "login"))
-		rts = login(argv);
 	else if(!stricmp(argv[0], "debug"))
 		rts = debug->DebugFifo(argv);
 	else if(!stricmp(argv[0], "ring"))
