@@ -460,161 +460,69 @@ bool Trunk::scrLibexec(void)
 	return false;
 }
 
-bool Trunk::scrRetry(void)
-{
-	int timer;
-	if(tgi.data)
-	{
-		Advance();
-		return true;
-	}
-	if(!database)
-	{
-		Error("retry-not-loaded");
-		return true;
-	}
-	timer = database->Lookup(tgi.seq, this);
-	if(timer < 0)
-	{
-		Error("retry-error");
-		return true;
-	}
-	if(!timer)
-	{
-		Advance();
-		return true;
-	}
-	data.sleep.wakeup = timer * 1000;
-	data.sleep.loops = 1;
-	data.sleep.rings = 0;
-	TrunkStep(TRUNK_STEP_SLEEP);
-	return false;
-}	
-
-bool Trunk::scrSubmit(void)
-{
-	char *err;
-
-	if(!database)
-		err = "no-database";
-	else
-		err = database->Submit(this);
-
-	if(err)
-	{
-		Error(err);
-		return true;
-	}
-	Advance();
-	return true;
-}
-
-bool Trunk::scrLogout(void)
-{
-	if(!session)
-	{
-		Error("no-login");
-		return true;
-	}
-	Logout();
-	Advance();
-	return true;
-}
-
-bool Trunk::scrSession(void)
-{
-	int timer;
-	scriptline_t *line = getScript();
-
-	if(!database)
-	{
-		Error("dbase-not-loaded");
-		return true;
-	}
-	if(!session)
-	{
-		Error("no-login");
-		return true;
-	}
-	timer = database->Session(++tgi.seq, line->cmd, this);
-	if(timer < 0)
-	{
-		Error("bad-session");
-		return true;
-	}
-	if(!timer)
-	{
-		Advance();
-		return true;
-	}
-	tgi.data = (void *)-1;
-	data.sleep.wakeup = timer * 1000;
-	data.sleep.loops = 1;
-	data.sleep.rings = 0;
-	TrunkStep(TRUNK_STEP_SLEEP);
-	return false;
-}
-
-bool Trunk::scrLogin(void)
-{
-	int timer;
-	if(!database)
-	{
-		Error("dbase-not-loaded");
-		return true;
-	}
-
-	setSymbol("login", database->getLoginSize());
-	Logout();
-	setSymbol("login", "");
-
-	timer = database->Login(++tgi.seq, this);
-
-	if(timer < 0)
-	{
-		Error("login-error");
-		return true;
-	}
-	if(!timer)
-	{
-		session = getSymbol("login");
-		Advance();
-		return true;
-	}
-	tgi.data = (void *)-1;
-	data.sleep.wakeup = timer * 1000;
-	data.sleep.loops = 1;
-	data.sleep.rings = 0;
-	TrunkStep(TRUNK_STEP_SLEEP);
-	return false;
-}
-
 bool Trunk::scrLookup(void)
 {
-	int timer;
+	char buffer[256];
+	strstream str(buffer, sizeof(buffer));
+	unsigned adapter = atoi(getValue("0"));
+	char *cp;
+	char *opt;
 
-	if(!database)
+	if(!adapter)
+		++tgi.seq;
+		
+	buffer[0] = 0;
+		
+	str << "L" << id << '\t' << tgi.seq << '\t' << getValue("default");
+	while(NULL != (opt = getOption(NULL)))
 	{
-		Error("dbase-not-loaded");
-		return true;
+		cp = getContent(opt);
+		str << '\t' << opt << '=' << cp;
 	}
-	timer = database->Lookup(++tgi.seq, this);
+	str << ends;
+	buffer[255] = 0;
 
-	tgi.data = (void *)-1;
-	if(timer < 0)
+	if(!network.Query(adapter, buffer, strlen(buffer) + 1))
 	{
-		Error("lookup-error");
+		Error("lookup-failed");
 		return true;
 	}
-	if(!timer)
-	{
-		Advance();
-		return true;
-	}
-	tgi.data = NULL;			
-	data.sleep.wakeup = timer * 1000;
-	data.sleep.loops = 1;
+	data.sleep.wakeup = keynetwork.getDatabaseDelay() * 1000;
 	data.sleep.rings = 0;
+	data.sleep.loops = 1;
+	TrunkStep(TRUNK_STEP_SLEEP);
+	return false;
+}
+
+bool Trunk::scrUpdate(void)
+{
+	char buffer[256];
+	strstream str(buffer, sizeof(buffer));
+	unsigned adapter = atoi(getValue("0"));
+	char *opt, *cp;
+
+	if(!adapter)
+		++tgi.seq;
+
+	buffer[0] = 0;
+
+	str << "U" << id << '\t' << tgi.seq << '\t' << getValue("default");
+	while(NULL != (opt = getOption(NULL)))
+	{
+		cp = getContent(opt);
+		str << '\t' << opt << opt << '=' << cp;
+	}
+	str << ends;
+	buffer[255] = 0;
+
+	if(!network.Query(adapter, buffer, strlen(buffer) + 1))
+	{
+		Error("updated-failed");
+		return true;
+	}
+	data.sleep.wakeup = keynetwork.getDatabaseDelay() * 1000;
+	data.sleep.rings = 0;
+	data.sleep.loops = 1;
 	TrunkStep(TRUNK_STEP_SLEEP);
 	return false;
 }
