@@ -241,10 +241,9 @@ static RETSIGTYPE final(int sig)
 	signal(SIGTERM, SIG_IGN);
 	signal(SIGQUIT, SIG_IGN);
 
+	network.Stop();
 	scheduler.Stop();
 	stopServers();
-	if(database)
-		database->Disconnect();
 
 	if(resolver)
 		delete resolver;
@@ -278,7 +277,6 @@ static void initial(int argc, char **argv)
 		{"node", 1, 0, 'n'},
 		{"test", 0, 0, 't'},
 		{"trace", 0, 0, 'T'},
-		{"database", 1, 0, 'a'},
 		{"version", 0, 0, 'V'},
 		{0, 0, 0, 0}};
 
@@ -313,9 +311,6 @@ static void initial(int argc, char **argv)
 			slog.level(SLOG_DEBUG);
 			plugins.setValue("debug", "trace");
 			break;			
-		case 'a':
-			plugins.setValue("database", optarg);
-			break;
 		case 't':
 			schedule = false;
 			test = true;
@@ -441,12 +436,10 @@ static void initial(int argc, char **argv)
 		plugins.loadDriver();
 		plugins.loadFeeds();
 		plugins.loadModules();
-		plugins.loadDatabase();
 		plugins.loadFunctions();
 		plugins.loadTranslators();
 		plugins.loadAuditing();
 		plugins.loadManagers();
-		plugins.loadStatMon();
 		driver->getImage();
 	}
 	catch(Driver *drv)
@@ -503,9 +496,6 @@ static void initial(int argc, char **argv)
 		final(-1);
 	}
 
-	if(database)
-		database->Connect();
-
 	if(keythreads.getResolver())
 		resolver = new Resolver();
 
@@ -514,6 +504,8 @@ static void initial(int argc, char **argv)
 	if(schedule)
 		scheduler.Start();
 
+	network.Start();
+
 	signal(SIGTERM, final);
 	signal(SIGQUIT, final);
 	signal(SIGINT, final);
