@@ -28,8 +28,8 @@ typedef	struct
 typedef	struct
 {
 	time_t update;
-	char name[16];
 	unsigned char ports;
+	char name[16];
 	char stat[255];
 } node_t;
 
@@ -55,6 +55,26 @@ public:
 	void Stop(void);
 };
 
+// the network service thread.
+
+class Network : public Thread, public UDPSocket, public MappedFile
+{
+private:
+	statnode_t *map;
+	time_t last;
+	char *getPath(void);
+	statnode_t *getNode(const char *name);
+	void Initial(void);
+	void Run(void);
+
+public:
+	Network();
+
+	bool Query(unsigned adapter, void *buf, size_t len);
+	void Stop(void);
+	void Refresh(int secs);
+};
+
 // the resolver is an optional service thread.
 
 class Resolver : public Server
@@ -70,5 +90,6 @@ public:
 	Resolver();
 };
 
+extern Network network;
 extern Scheduler scheduler;
 extern int tgipipe[2];
