@@ -41,7 +41,6 @@ ScriptInterp((aaScript *)driver, keymemory.getSymbolSize(), keymemory.getPageSiz
 	start = idle = 0;
 	thread = NULL;
 	script = NULL;
-	session = NULL;
 	manager = NULL;
 	digits = 0;
 
@@ -107,17 +106,6 @@ void Trunk::Commit(scriptsymbol_t *sym)
 		digits = strlen(dtmf.bin.data);
 }
 
-void Trunk::Logout(void)
-{
-	if(!session)
-		return;
-
-	if(database)
-		database->Logout(this);
-
-	session = NULL;
-}
-
 void Trunk::setConstant(const char *id, const char *data)
 {
 	scriptsymbol_t *sym = ScriptSymbol::getEntry(id, strlen(data));
@@ -278,9 +266,6 @@ bool Trunk::Attach(const char *name)
 	if(!start)
 		time(&start);
 
-	if(database)
-		database->Initialize(this);
-
 	debug->DebugState(this, "attach script");
 	return true;
 }
@@ -297,7 +282,6 @@ void Trunk::Detach(void)
 
 	getName(buffer);
 	slog(SLOG_DEBUG) << buffer << ": hi water mark at detach; " << getPages() << endl;
-	Logout();
 	buffer[0] = 0;
 	while(i < cdrc)
 	{
@@ -327,8 +311,6 @@ void Trunk::Detach(void)
 	if(tgi.pid)
 		kill(tgi.pid, SIGHUP);
 	tgi.pid = 0;
-	if(database)
-		database->Finalize(this);
 	debug->DebugState(this, "detach script");
 }
 
